function [icx,ice,ich,icr,irx,ire,irh,irr] = tgraph(image,Kc,Kr)
%
% tgraph: does complete topo processing of image
% On input:
%     image: 2D image
%     Kc: column size for parabola fit
%     Kr: row size for parabola fit
% On output:
%     icx: 2D array with column response
%     ice: 2D array with column error
%     ich: 2D array with column height
%     icr: 2D array with column radius
%     irx: 2D array with row response
%     ire: 2D array with row error
%     irh: 2D array with row height
%     irr: 2D array with row adius
% Call:
%     [icx,ice,ich,icr,irx,ire,irh,irr] = tgraph(image,Kc,Kr)
%

[m n] = size(image);
%doing_cols_cba = 0;
[icc,icb,ica] = qf2dcol(image,Kc);
%doing_cols_xehr = 1;
[icx,ice,ich,icr] = q2par(image,Kc,icc,icb,ica);
imaget = image';
%doing_rows_bca = 2;
[irct,irbt,irat] = qf2dcol(imaget,Kr);
%doing_rows_xehr = 3;
[irxt,iret,irht,irrt] = q2par(imaget,Kr,irct,irbt,irat);
irc = irct';
irb = irbt';
ira = irat';
irx = irxt';
ire = iret';
irh = irht';
irr = irrt';
